/*
 * Copyright (C) 2008 Luke Kenneth Casson Leighton <lkcl@lkcl.net>
 * Copyright (C) 2008 Alp Toker <alp@atoker.com>
 * Copyright (C) 2008 Apple Inc.
 */

#include "config.h"

#include <wtf/GetPtr.h>
#include "CSSRule.h"
#include "CSSValue.h"
#include "CanvasPixelArray.h"
#include "DOMWindow.h"
#include "Element.h"
#include "Event.h"
#include "GDOMBinding.h"
#include "GDOMObject.h"
#include "HTMLCollection.h"
#include "Node.h"
#include "StyleSheet.h"
#include "Text.h"
#include "XMLSerializer.h"
#include "gdom/GStringConvert.h"
#include "gdom/GdomDOMObject.h"
#include "gdom/GdomNode.h"
#include "gdom/GdomXMLSerializer.h"
#include "gdom/PrivateGdomDOMObject.h"
#include "gdom/PrivateGdomNode.h"
#include "gdom/PrivateGdomXMLSerializer.h"
#include "gdom/PrivateIntGdomNode.h"
#include "gdom/PrivateIntGdomXMLSerializer.h"

namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore

namespace WebCore {
gpointer toGDOM(WebCore::XMLSerializer* obj)
{
    return WebCore::cacheDOMObject<WebCore::XMLSerializer, GDOMXMLSerializer>(obj);
}
} /* namespace WebCore */
extern "C" {

GDOMXMLSerializer::GDOMXMLSerializer(PassRefPtr<WebCore::XMLSerializer> impl)
    : GDOMObject()
    , m_impl(impl)
{
}

GDOMXMLSerializer::~GDOMXMLSerializer()
{
    m_impl.get()->deref();
    WebCore::GDOMScriptInterpreter::forgetDOMObject(m_impl.get());

}

gchar *
gdom_xml_serializer_serialize_to_string (GdomXMLSerializer *thiz, GdomNode * node)
{
    g_return_val_if_fail (thiz, 0);
    WebCore::XMLSerializer * item = (gdom_xml_serializer_get_private(thiz));
    g_return_val_if_fail (item, 0);
    g_return_val_if_fail (node, 0);
    WebCore::Node * _g_node = (gdom_node_get_private(node));
    g_return_val_if_fail (_g_node, 0);
    WebCore::ExceptionCode ec = 0;
    gchar * res = _G_GET_UTF8(item->serializeToString(_g_node, ec));
    return res;

}

} /* extern "C" */


#include "config.h"
#include "glib-object.h"
#include <webkit/webkitdefines.h>
#include <webkit/webkitprivate.h> 
#include "DOMWindow.h" /* yukk: TODO - make this optional */
#include "Node.h" /* yukk: TODO - make this optional */
#include "NamedNodeMap.h" /* yukk: TODO - make this optional */
#include "CanvasPattern.h" /* yukk: TODO - make this optional */
#include "CanvasGradient.h" /* yukk: TODO - make this optional */
#include "CanvasStyle.h" /* yukk: TODO - make this optional */
#include "CanvasRenderingContext2D.h" /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomDOMObject.h> /* yukk: TODO - make this optional */
#include <gdom/GdomEventTargetNode.h> /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomEventTargetNode.h> /* yukk: TODO - make this optional on EventTarget*/
#include "XMLSerializer.h"
#include <gdom/GdomXMLSerializer.h>
#include <gdom/PrivateGdomXMLSerializer.h>
#include <gdom/PrivateIntGdomXMLSerializer.h>
#include <gdom/GdomXMLSerializerprops.h>

#include "gdom/GStringConvert.h"

#include "CanvasPixelArray.h"
#include "Event.h"
#include "Text.h"
#include "CSSValue.h"
#include "CSSRule.h"
#include "HTMLCollection.h"
#include "StyleSheet.h"
#include "Document.h"
#include "webkitmarshal.h"
#include <gdom/GdomEvent.h>



namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore



G_BEGIN_DECLS

G_DEFINE_TYPE(GdomXMLSerializer, gdom_xml_serializer, GDOM_TYPE_DOM_OBJECT);

/*
struct _GdomXMLSerializerPrivate {
    class WebCore::XMLSerializer *item;
};

#define GDOM_XML_SERIALIZER_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE((obj), GDOM_TYPE_XML_SERIALIZER, GdomXMLSerializerPrivate))
*/
G_END_DECLS
WebCore::XMLSerializer *
gdom_xml_serializer_get_private(GdomXMLSerializer *request)
{
    GDOMXMLSerializer *res;
    res = static_cast<GDOMXMLSerializer*>(gdom_dom_object_get_private(GDOM_DOM_OBJECT(request)));
    return static_cast<WebCore::XMLSerializer*>(res->impl());
}

G_BEGIN_DECLS

enum {
    BROWSER_EVENT,
    LAST_SIGNAL
};

static guint event_signals[LAST_SIGNAL] = { 0, };

enum {
    PROP_0,
};


static void gdom_xml_serializer_finalize(GObject* object)
{
    /*GdomXMLSerializer* request = GDOM_XML_SERIALIZER(object);*/
    /*GdomXMLSerializerPrivate* priv = request->priv;*/

    /*GObjectClass *parent_class = g_type_class_peek (g_type_peek_parent (GDOM_TYPE_DOM_OBJECT));*/

    /* Free any memory or close any files */

    /*parent_class-> finalize (object);*/

    G_OBJECT_CLASS(gdom_xml_serializer_parent_class)->finalize(object);
}

static void gdom_xml_serializer__set_property_fn(GObject * object, guint prop_id,
                     const GValue * value,
                     GParamSpec * pspec)
{
    GdomXMLSerializer *self = GDOM_XML_SERIALIZER(object);
    WebCore::XMLSerializer * gself = (gdom_xml_serializer_get_private(self));
    switch (prop_id) {
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_xml_serializer__get_property_fn(GObject * object, guint prop_id,
                     GValue * value,
                     GParamSpec * pspec)
{
    GdomXMLSerializer *self = GDOM_XML_SERIALIZER(object);
    WebCore::XMLSerializer * gself = (gdom_xml_serializer_get_private(self));
    switch (prop_id) {
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_xml_serializer_class_init(GdomXMLSerializerClass* requestClass)
{
    GObjectClass *g_klass = G_OBJECT_CLASS (requestClass);
    g_klass->finalize = gdom_xml_serializer_finalize;
    g_klass->set_property = gdom_xml_serializer__set_property_fn;
    g_klass->get_property = gdom_xml_serializer__get_property_fn;





    /*g_type_class_remove_private(requestClass, sizeof(GdomXMLSerializerPrivate));*/
}

static void gdom_xml_serializer_init(GdomXMLSerializer* request)
{
    /*GdomXMLSerializerPrivate* priv = GDOM_XML_SERIALIZER_GET_PRIVATE(request);
    request->priv = priv;*/
}

} /* extern "C" */

